@@ -6,7 +6,7 @@ Created on Sat Jun  1 15:11:33 2019
 @author: Gabriele Coiana
 """
 import numpy as np
-import  read,  util#,  plot 
+from decomp import  read,  util#,  plot 
 import sys
 
 ## =============================================================================
