@@ -22,10 +22,11 @@ def figsize(scale):
 
     return fig_size
 
-import matplotlib as mpl
-mpl.use('pgf')
 #import warnings
 #warnings.filterwarnings('ignore') 
+import matplotlib as mpl
+mpl.use('pgf')
+
 import matplotlib.pyplot as plt
 from mpl_toolkits.mplot3d import Axes3D
 from matplotlib import animation
@@ -227,14 +228,14 @@ def save_proj(x,y,ytot, k,Ruc, eigvec,freq,n,namedir,masses, params, max_Z):
         ax.text(omega0+gamma, y_max/2, 'width='+str(np.round(gamma,2)))
         ax.axvline(x=omega0, linestyle=':', color='black')
         #vline1 = ax.plot(np.repeat(omega0,100),np.linspace(0,y_max/2,100),':' ,c='grey')
-#        vline1 = ax.plot(np.repeat(omega0+gamma/2,100),np.linspace(0,y_max/2,100) ,c='orangered')
+        #vline1 = ax.plot(np.repeat(omega0+gamma/2,100),np.linspace(0,y_max/2,100) ,c='orangered')
         ax.axvspan(omega0-gamma/2, omega0+gamma/2, ymin=0, ymax=1, color='grey', alpha=0.2)
     
 
     
       
     graph3, = ax.plot(np.repeat(freq,100),np.linspace(0,y.max(),100), c='red', label='freq from dispersion')
-    plt.legend(handles=[graph1, graph3, graph4])
+    plt.legend(handles=[graph1, graph3])
     
 #    plt.subplots_adjust(top=0.85)
 #    if(np.allclose(k,[0,0,0])):
@@ -254,7 +255,7 @@ def save_proj(x,y,ytot, k,Ruc, eigvec,freq,n,namedir,masses, params, max_Z):
     return 
 
     
-def plot_k(f, data, data_projected, ks,freqs, max_Z, branches,  title=''):
+def plot_k(f, data, data_projected, indexes,freqs, max_Z, branches,  title=''):
     """
     Plotting the dispersion from MD and from phonon theory.
     
@@ -264,6 +265,44 @@ def plot_k(f, data, data_projected, ks,freqs, max_Z, branches,  title=''):
         indexes = list of all kpoints
         freqs = frequencies from phonopy
     """
+    
+    pgf_with_latex = {                      # setup matplotlib to use latex for output
+
+    "pgf.texsystem": "pdflatex",        # change this if using xetex or lautex
+
+    "text.usetex": True,                # use LaTeX to write all text
+
+    "font.family": "serif",
+
+    "font.serif": [],                   # blank entries should cause plots to inherit fonts from the document
+
+    "font.sans-serif": [],
+
+    "font.monospace": [],
+
+    "axes.labelsize": 16,                # LaTeX default is 10pt font.     "text.fontsize": 10,
+
+    "legend.fontsize": 12,               # Make the legend/label fonts a little smaller
+
+    "xtick.labelsize": 16,
+
+    "ytick.labelsize": 16,
+
+    "figure.figsize": figsize(1.4),       # default fig size of 0.9 textwidth
+
+    "pgf.preamble": [
+
+        r"\usepackage[utf8x]{inputenc}",    # use utf8 fonts becasue your computer can handle it :)
+
+        r"\usepackage[T1]{fontenc}",        # plots will be generated using this preamble
+
+        ]
+
+    }
+
+    mpl.rcParams.update(pgf_with_latex)
+
+    
     fig,ax = plt.subplots()
     plt.suptitle('Spectrum via MD and phonon theory')
     #ax.set_title(title)
@@ -277,35 +316,36 @@ def plot_k(f, data, data_projected, ks,freqs, max_Z, branches,  title=''):
     dk = kk[1] - kk[0]
     
 
-
-    indexes = from_band(ks)
+#    indexes = from_band(ks)
+    
 
     #norm = [plt.cm.colors.Normalize(vmax=abs(data[0::1,l]).max(), vmin=-abs(data[0::1,l]).min()) for l in range(len(data[0,:]))]
-    if(max_Z > np.max(data) or max_Z < 0.0):
-        max_Z = np.max(data)
-    
-    norm = plt.cm.colors.Normalize(vmax=max_Z, vmin=0)
-    cmps = [plt.cm.Purples, plt.cm.Reds, plt.cm.Greens]
-    
-    if(branches[1]- branches[0] > 3): #plot whole spectrum
+    if(len(branches) == tot_branches): #plot whole spectrum
         print('Drawing the whole spectrum...')
-        for j in range(len(data[0::1,0])):  
+        if(max_Z > np.max(data) or max_Z < 0.0):
+            max_Z = np.max(data)
+        norm = plt.cm.colors.Normalize(vmax=max_Z, vmin=0)
+        for j in range(0,len(data[0::1,0])):  
             # this is the whole spectrum
             ax.bar(kk, np.repeat(df,N), bottom=offset-df/2,  color=plt.cm.Blues(norm(data[j,:])), tick_label=indexes, align='center', width=dk, alpha=None)
             offset = offset + df
             
     else:   #print only those branches 
-        print('Drawing spectrum branches from ', branches[0], 'to ', branches[1])
-        for j in range(len(data[0::1,0])):      
-            if(np.size(data_projected) != 0):
-                for mm in range(len(data_projected[0,:,0])):
-                    if(np.max(data_projected[j,mm,:]) == np.max(data_projected[:,mm,:])): #this is just for the legend
-                        ax.bar(kk, np.repeat(df,N), bottom=offset-df/2,  color=cmps[mm](norm(data_projected[j,mm,:])), tick_label=indexes, align='center', width=dk, alpha=.5)
-                        kpoint_of_max = np.argwhere(data_projected[j,mm,:] == np.max(data_projected[j,mm,:]))[0,0]
-                        bar = ax.bar(kk[kpoint_of_max], df, bottom=offset[0]-df/2,  color=cmps[mm](norm(data_projected[j,mm,kpoint_of_max])),  align='center', width=dk, alpha=.5, label='mode '+str(branches[0]+mm))
-                    else:
-                        ax.bar(kk, np.repeat(df,N), bottom=offset-df/2,  color=cmps[mm](norm(data_projected[j,mm,:])), tick_label=indexes, align='center', width=dk, alpha=.5)
-    
+        if(max_Z > np.max(data_projected) or max_Z < 0.0):
+             max_Z = np.max(data_projected)
+        norm = plt.cm.colors.Normalize(vmax=max_Z, vmin=0)
+        cmps = [plt.cm.Purples, plt.cm.Reds, plt.cm.Greens, plt.cm.Greys, plt.cm.Oranges]
+        print('Drawing spectrum branches ', branches)
+        for j in range(0,len(data[0::1,0])):
+            for mm in range(len(data_projected[0,:,0])):
+                if(np.max(data_projected[j,mm,:]) == np.max(data_projected[:,mm,:])): #this is just for the legend
+                    ax.bar(kk, np.repeat(df,N), bottom=offset-df/2,  color=cmps[mm]((data_projected[j,mm,:])), tick_label=indexes, align='center', width=dk, alpha=.5)
+                    kpoint_of_max = np.argwhere(data_projected[j,mm,:] == np.max(data_projected[j,mm,:]))[0,0]
+                    bar = ax.bar(kk[kpoint_of_max], df, bottom=offset[0]-df/2,  color=cmps[mm]((data_projected[j,mm,kpoint_of_max])),  align='center', width=dk, alpha=.5, label='mode '+str(branches[0]+mm))
+                else:
+#                    print(j, (data_projected[j,mm,:]))
+                    ax.bar(kk, np.repeat(df,N), bottom=offset-df/2,  color=cmps[mm]((data_projected[j,mm,:])), tick_label=indexes, align='center', width=dk, alpha=.5)
+
             offset = offset + df
    
     
@@ -316,7 +356,6 @@ def plot_k(f, data, data_projected, ks,freqs, max_Z, branches,  title=''):
     for l in range(num_dispersions):
         for j in range(tot_branches):
             ax2.scatter(kk,freqs[l][:,j], marker='x', c=colours[l], s=100)
-            
         ax2.scatter(kk,freqs[l][:,tot_branches-1],  marker='x', s=100, c=colours[l], label=title[l])
     ax2.get_shared_y_axes().join(ax, ax2)
     
@@ -325,9 +364,12 @@ def plot_k(f, data, data_projected, ks,freqs, max_Z, branches,  title=''):
 
     plt.ylim([f[0], f[-1]])
     plt.legend(handles=handles, labels=labels)
-    plt.show()
-    fig.savefig('spectrum_branches_'+str(branches[0])+'_to_'+str(branches[1])+'.pdf')
-    fig.savefig('spectrum_branches_'+str(branches[0])+'_to_'+str(branches[1])+'.png')
+    ax.tick_params(axis='both', which='major', labelsize=15, width=2 , length=6, direction='in', top=True, left=True, bottom=True)
+    ax2.tick_params(axis='y', which='major', labelsize=15, width=2 , length=6, direction='in')
+    plt.rcParams['axes.linewidth'] = 2
+#    plt.show()
+    fig.savefig('spectrum_branches_'+str(branches)+'.pdf')
+    fig.savefig('spectrum_branches_'+str(branches)+'.png')
     return
     
 
