@@ -158,6 +158,41 @@ if(mode==4):
     
 
         
+if(mode==5):
+    # take the path the user inputs and find all the k points you can plot
+    ks_path, x_labels, distances = read.read_path(kinput, Nqpoints, labels, Hk) #you use this only to get x_labels, you should include this into read_phonopy
+    num_modes = len(modes)
+
+    
+    freq = np.loadtxt('freq')
+    meta = len(freq)
+    ZQS = np.zeros((meta, len(qpoints_scaled)))
+    ZQS_proj = np.zeros((meta, num_modes, len(qpoints_scaled)))
+    count = 0
+    accepted_qpoints = []
+    freqs_from_disp = np.zeros((len(qpoints_scaled),tot_atoms_uc*3))
+    for i in range(Nqpoints):
+        to_skip = (1+meta)*i
+        qpoint = np.genfromtxt('Zqs',skip_header=to_skip+0, max_rows=1)
+        for j in range(len(qpoints_scaled)):
+            if(np.allclose(qpoint, qpoints_scaled[j]) and (qpoint.tolist() not in accepted_qpoints)):
+                accepted_qpoints.append(qpoint.tolist())
+                for m in range(Nqpoints):
+                    if(np.allclose(qpoint,qpoints_scaled[m])):
+                        freqs_from_disp[count, :] = freqs_disp[m,:]
+                        break
+                Zq = np.genfromtxt('Zqs',skip_header=to_skip+1, max_rows=meta)
+                if(num_modes == tot_atoms_uc*3):
+                    ZQS[:,count] = Zq[:,0]
+                else:
+                    for b in range(len(modes)):
+                        mm = modes[b]
+                        ZQS_proj[:,b,i] = Zq[:,mm+1]
+                count = count + 1
+
+    plot.plot_k(freq,ZQS,ZQS_proj, x_labels,[freqs_from_disp],max_Z,modes,title=['freq from 0K dispersion'])
+
+    
     
     
     
